@@ -139,7 +139,7 @@ class ProgramTester:
 		with open("./tester/student/student_{}".format(solution_filename), 'w') as s:
 			s.write("# Command args: {}".format(args))
 			for o in out:
-				s.write(o)
+				s.write(o + "\n")
 		return self.compare_output(out, self.read_output_file("./tester/solution/{}".format(solution_filename)), print_diff)
 		
 	def remove_text_inside_brackets(self, text, brackets="()[]"):
